@@ -178,7 +178,7 @@ namespace Oxygen
 
         //@}
 
-        //* returns first widget matching given class, or 0L if none
+        //* returns first widget matching given class, or nullptr if none
         template<typename T> T findParent( const QWidget* ) const;
 
         //* enability
@@ -285,11 +285,11 @@ namespace Oxygen
         T WindowManager::findParent( const QWidget* widget ) const
     {
 
-        if( !widget ) return 0L;
+        if( !widget ) return nullptr;
         for( QWidget* parent = widget->parentWidget(); parent; parent = parent->parentWidget() )
         { if( T cast = qobject_cast<T>(parent) ) return cast; }
 
-        return 0L;
+        return nullptr;
     }
 
 }
